@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "julia-snail" "1.3.2"
+(define-package "julia-snail" "20250910.703"
   "Julia Snail."
   '((emacs      "26.2")
     (dash       "2.16.0")
@@ -8,5 +8,5 @@
     (spinner    "1.7.3")
     (popup      "0.5.9"))
   :url "https://github.com/gcv/julia-snail"
-  :commit "4a0adf835dc650adcbec51bd0792ef53efbad65b"
-  :revdesc "4a0adf835dc6")
+  :commit "7b50882f5aec33aa9c120f89c2e604f71bdd7a26"
+  :revdesc "7b50882f5aec")
