@@ -3,8 +3,8 @@
 
 ;; URL: https://github.com/gcv/julia-snail
 ;; Package-Requires: ((emacs "26.2") (dash "2.16.0") (julia-mode "0.3") (s "1.12.0") (spinner "1.7.3") (popup "0.5.9"))
-;; Package-Version: 1.3.2
-;; Package-Revision: 4a0adf835dc6
+;; Package-Version: 20250910.703
+;; Package-Revision: 7b50882f5aec
 ;; Created: 2019-10-27
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -444,6 +444,7 @@ MODULE can be:
      (with-syntax-table stab
        (modify-syntax-entry ?. "_")
        (modify-syntax-entry ?@ "_")
+       (modify-syntax-entry ?! "_")
        (modify-syntax-entry ?= " ")
        (modify-syntax-entry ?$ " ")
        ,@body)))
@@ -580,7 +581,7 @@ Returns nil if the poll timed out, t otherwise."
                                    (concat "julia-snail-" checksum "/"))))
     (unless (file-exists-p snail-remote-dir)
       (make-directory snail-remote-dir)
-      (let ((default-directory (file-name-directory (symbol-file 'julia-snail))))
+      (let ((default-directory (file-name-directory (locate-library "julia-snail"))))
         (cl-loop for f in julia-snail--julia-files do
                  (if (file-directory-p f)
                      (make-directory (concat snail-remote-dir f))
@@ -1355,13 +1356,6 @@ evaluated in the context of MODULE."
       ;; make sure that the string which arrives to the completion provider on the server starts with "\\".
       (when (s-equals-p (substring identifier 0 1) "\\")
         (setq prefix "\\"))
-      ;; check if identifier at point is inside a string and attach the opening quotes so
-      ;; we get path completion.
-      (when-let (prev (char-before (car bounds)))
-        (when (char-equal prev ?\")
-          (setq identifier (concat "\\\"" identifier))
-          ;; TODO: add support for Windows paths (splitting on "\\" when appropriate)
-          (setq split-on "/")))
       ;; If identifier is not a string, we split on "." so that completions of
       ;; the form Module.f -> Module.func work (since
       ;; `julia-snail--repl-completions' will return only "func" in this case)
@@ -1668,7 +1662,7 @@ evaluated in the context of MODULE."
 (defun julia-snail--extension-load (extname)
   (let ((extsym (julia-snail--extension-symbol extname)))
     (unless (featurep extsym)
-      (let* ((current-file (symbol-file 'julia-snail))
+      (let* ((current-file (locate-library "julia-snail"))
              (extdir (concat (file-name-directory current-file)
                              (file-name-as-directory "extensions")
                              (file-name-as-directory (symbol-name extname))))
@@ -1825,6 +1819,32 @@ This will occur in the context of the Main module, just as it would at the REPL.
                                          filename
                                          (julia-snail--construct-module-path module)))))))))
 
+;; Trimmed down version of julia-snail-send-buffer-file which only analyzes the "include" statements without running the code
+(defun julia-snail-analyze-includes ()
+  "Analyze the current buffer's file for include statements"
+  (interactive)
+  (let* ((filename (julia-snail--efn (buffer-file-name (buffer-base-buffer))))
+         (includes (julia-snail--cst-includes (current-buffer))))
+    (when (or (not (buffer-modified-p))
+              (y-or-n-p (format "'%s' is not saved, analyze in Julia anyway? " filename)))
+      (if (eq :error includes)
+          (let ((error-buffer
+                 (julia-snail--message-buffer
+                  repl-buf
+                  "error"
+                  (concat filename
+                          " analyzed in Julia, but the Snail parser failed.\n\n"
+                          "Please report this as a parser bug:\n\n"
+                          "https://github.com/gcv/julia-snail/issues\n\n"
+                          "Please try to narrow down the code which Snail fails to parse.\n"
+                          "The easiest way of doing this is to bisect the failing source file by\n"
+                          "commenting out successive halves.\n"
+                          "The more information about code which Snail cannot parse you include in the bug\n"
+                          "report, the easier it will be to fix."))))
+            (pop-to-buffer error-buffer))
+        ;; successful load
+        (julia-snail--module-merge-includes filename includes)))))
+
 (defun julia-snail-package-activate (dir)
   "Activate a Pkg project located in DIR in the Julia REPL."
   (interactive "DProject directory: ")
